==> vtigercrm-5.0.3.tgz: vtigercrm/modules/Leads/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Leads',
'LBL_DIRECT_REPORTS_FORM_NAME'=>'Direct Reports',
'LBL_MODULE_TITLE'=>'Leads: Home',
'LBL_SEARCH_FORM_TITLE'=>'Lead Search',
'LBL_LIST_FORM_TITLE'=>'Lead List',
'LBL_NEW_FORM_TITLE'=>'New Lead',
'LBL_LEAD_OPP_FORM_TITLE'=>'Contact-Opportunity:',
'LBL_LEAD'=>'Lead:',
'LBL_ADDRESS_INFORMATION'=>'Address Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',

'LBL_LIST_NAME'=>'Name',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_LIST_COMPANY'=>'Company',
'LBL_LIST_WEBSITE'=>'Website',
'LBL_LIST_LEAD_NAME'=>'Lead Name',
'LBL_LIST_EMAIL'=>'Email',
'LBL_LIST_PHONE'=>'Phone',
'LBL_LIST_LEAD_ROLE'=>'Role',

'LBL_NAME'=>'Name:',
'LBL_LEAD_NAME'=>'Lead Name:',
'LBL_LEAD_INFORMATION'=>'Lead Information',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_PHONE'=>'Phone:',
'LBL_COMPANY'=>'Company:',
'LBL_DESIGNATION'=>'Designation:',
'LBL_PHONE'=>'Phone:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_MOBILE'=>'Mobile:',
'LBL_EMAIL'=>'Email:',
'LBL_LEAD_SOURCE'=>'Lead Source:',
'LBL_LEAD_STATUS'=>'Lead Status:',
'LBL_WEBSITE'=>'Website:',
'LBL_FAX'=>'Fax:',
'LBL_INDUSTRY'=>'Industry:',
'LBL_ANNUAL_REVENUE'=>'Annual Revenue:',
'LBL_RATING'=>'Rating:',
'LBL_LICENSE_KEY'=>'License Key:',
'LBL_NO_OF_EMPLOYEES'=>'No. of Employees:',
'LBL_YAHOO_ID'=>'Yahoo! ID:',

'LBL_ADDRESS_STREET'=>'Street:',
'LBL_ADDRESS_POSTAL_CODE'=>'Postal Code:',
'LBL_ADDRESS_CITY'=>'City:',
'LBL_ADDRESS_COUNTRY'=>'Country:',
'LBL_ADDRESS_STATE'=>'State:',
'LBL_ADDRESS'=>'Address:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',
'LBL_DESCRIPTION'=>'Description:',

'LBL_CONVERT_LEAD'=>'Convert Lead:',
'LBL_CONVERT_LEAD_INFORMATION'=>'Convert Lead Information',
'LBL_ACCOUNT_NAME'=>'Account Name',
'LBL_POTENTIAL_NAME'=>'Potential Name',
'LBL_POTENTIAL_CLOSE_DATE'=>'Potential Close Date',
'LBL_POTENTIAL_AMOUNT'=>'Potential Amount',
'LBL_POTENTIAL_SALES_STAGE'=>'Potential Sales Stage',


'NTC_DELETE_CONFIRMATION'=>'Are you sure you want to delete this record?',
'NTC_REMOVE_CONFIRMATION'=>'Are you sure you want to remove this contact from this case?',
'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION'=>'Are you sure you want to remove this record as a direct vtiger_report?',
'NTC_REMOVE_OPP_CONFIRMATION'=>'Are you sure you want to remove this contact from this opportunity?',
'ERR_DELETE_RECORD'=>"en_us A record number must be specified to delete the contact.",
'NTC_COPY_PRIMARY_ADDRESS'=>'Copy primary address to alternate address',
'NTC_COPY_ALTERNATE_ADDRESS'=>'Copy alternate address to primary address',

// Added vtiger_fields in fetchfile.php, import.php -- crm4-Beta
'LBL_COLON'=>' : ', 
'LBL_IMPORT_LEADS'=>'Import Leads',
'LBL_LEADS_FILE_LIST'=>'Leads File List',
'LBL_INSTRUCTIONS'=>'Instructions',
'LBL_KINDLY_PROVIDE_AN_XLS_FILE'=>'Kindly provide an .xls file alone as input',
'LBL_PROVIDE_ATLEAST_ONE_FILE'=>'Please provide at least one file as input',

'LBL_NONE'=>'None',
'LBL_ASSIGNED_TO'=>'Assigned To:',
'LBL_SELECT_LEAD'=>'Select Lead',
'LBL_GENERAL_INFORMATION'=>'General Information',
'LBL_DO_NOT_CREATE_NEW_POTENTIAL'=>'Do not create a New Potential upon Conversion',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TASK'=>'New Task',
'LBL_TASK_TITLE'=>'Tasks',
'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',
'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',
'LBL_NEW_EMAIL'=>'New Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'New Note',
'LBL_NOTE_TITLE'=>'Notes',
'LBL_NEW_ATTACHMENT'=>'New Attachment',
'LBL_ATTACHMENT_TITLE'=>'Attachments',


//Added vtiger_fields after RC1 - Release 
'LBL_ALL'=>'All',
'LBL_CONTACTED'=>'Contacted',
'LBL_LOST'=>'Lost',
'LBL_HOT'=>'Hot',
'LBL_COLD'=>'Cold',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Lead Tools',

'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE'=>'Select template to Mail Merge:',

//Added for 4GA
'Salutation'=>'Salutation',
'First Name'=>'First Name',
'Phone'=>'Phone',
'Last Name'=>'Last Name',
'Mobile'=>'Mobile',
'Company'=>'Company',
'Fax'=>'Fax',
'Designation'=>'Designation',
'Email'=>'Email',
'Lead Source'=>'Lead Source',
'Website'=>'Website',
'Annual Revenue'=>'Annual Revenue',
'Lead Status'=>'Lead Status',
'Industry'=>'Industry',
'Rating'=>'Rating',
'No Of Employees'=>'No Of Employees',
'Assigned To'=>'Assigned to',
'Yahoo Id'=>'Yahoo Id',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Street'=>'Street',
'Postal Code'=>'Postal Code',
'City'=>'City',
'Country'=>'Country',
'State'=>'State',
'Description'=>'Description',
'Po Box'=>'PO Box',
'Campaign Source'=>'Campaign Source',
//Added for CustomView 4.2 Release
'Name'=>'Name',
'LBL_NEW_LEADS'=>'My New Leads',

//Added for Existing Picklist Entries

'--None--'=>'--None--',
'Mr.'=>'Mr.',
'Ms.'=>'Ms.',
'Mrs.'=>'Mrs.',
'Dr.'=>'Dr.',
'Prof.'=>'Prof.',

'Acquired'=>'Acquired',
'Active'=>'Active',
'Market Failed'=>'Market Failed',
'Project Cancelled'=>'Project Cancelled',
'Shutdown'=>'Shutdown',

'Apparel'=>'Apparel',
'Banking'=>'Banking',
'Biotechnology'=>'Biotechnology',
'Chemicals'=>'Chemicals',
'Communications'=>'Communications',
'Construction'=>'Construction',
'Consulting'=>'Consulting',
'Education'=>'Education',
'Electronics'=>'Electronics',
'Energy'=>'Energy',
'Engineering'=>'Engineering',
'Entertainment'=>'Entertainment',
'Environmental'=>'Environmental',
'Finance'=>'Finance',
'Food & Beverage'=>'Food & Beverage',
'Government'=>'Government',
'Healthcare'=>'Healthcare',
'Hospitality'=>'Hospitality',
'Insurance'=>'Insurance',
'Machinery'=>'Machinery',
'Manufacturing'=>'Manufacturing',
'Media'=>'Media',
'Not For Profit'=>'Not For Profit',
'Recreation'=>'Recreation',
'Retail'=>'Retail',
'Shipping'=>'Shipping',
'Technology'=>'Technology',
'Telecommunications'=>'Telecommunications',
'Transportation'=>'Transportation',
'Utilities'=>'Utilities',
'Other'=>'Other',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Existing Customer',
'Self Generated'=>'Self Generated',
'Employee'=>'Employee',
'Partner'=>'Partner',
'Public Relations'=>'Public Relations',
'Direct Mail'=>'Direct Mail',
'Conference'=>'Conference',
'Trade Show'=>'Trade Show',
'Web Site'=>'Web Site',
'Word of mouth'=>'Word of mouth',

'Attempted to Contact'=>'Attempted to Contact',
'Cold'=>'Cold',
'Contact in Future'=>'Contact in Future',
'Contacted'=>'Contacted',
'Hot'=>'Hot',
'Junk Lead'=>'Junk Lead',
'Lost Lead'=>'Lost Lead',
'Not Contacted'=>'Not Contacted',
'Pre Qualified'=>'Pre Qualified',
'Qualified'=>'Qualified',
'Warm'=>'Warm',
     

);

?>

==> vtigercrm-5.0.4.tgz: vtigercrm/modules/Leads/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Leads',
'LBL_DIRECT_REPORTS_FORM_NAME'=>'Direct Reports',
'LBL_MODULE_TITLE'=>'Leads: Home',
'LBL_SEARCH_FORM_TITLE'=>'Lead Search',
'LBL_LIST_FORM_TITLE'=>'Lead List',
'LBL_NEW_FORM_TITLE'=>'New Lead',
'LBL_LEAD_OPP_FORM_TITLE'=>'Contact-Opportunity:',
'LBL_LEAD'=>'Lead:',
'LBL_ADDRESS_INFORMATION'=>'Address Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',

'LBL_LIST_NAME'=>'Name',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_LIST_COMPANY'=>'Company',
'LBL_LIST_WEBSITE'=>'Website',
'LBL_LIST_LEAD_NAME'=>'Lead Name',
'LBL_LIST_EMAIL'=>'Email',
'LBL_LIST_PHONE'=>'Phone',
'LBL_LIST_LEAD_ROLE'=>'Role',

'LBL_NAME'=>'Name:',
'LBL_LEAD_NAME'=>'Lead Name:',
'LBL_LEAD_INFORMATION'=>'Lead Information',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_PHONE'=>'Phone:',
'LBL_COMPANY'=>'Company:',
'LBL_DESIGNATION'=>'Designation:',
'LBL_PHONE'=>'Phone:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_MOBILE'=>'Mobile:',
'LBL_EMAIL'=>'Email:',
'LBL_LEAD_SOURCE'=>'Lead Source:',
'LBL_LEAD_STATUS'=>'Lead Status:',
'LBL_WEBSITE'=>'Website:',
'LBL_FAX'=>'Fax:',
'LBL_INDUSTRY'=>'Industry:',
'LBL_ANNUAL_REVENUE'=>'Annual Revenue:',
'LBL_RATING'=>'Rating:',
'LBL_LICENSE_KEY'=>'License Key:',
'LBL_NO_OF_EMPLOYEES'=>'No. of Employees:',
'LBL_YAHOO_ID'=>'Yahoo! ID:',

'LBL_ADDRESS_STREET'=>'Street:',
'LBL_ADDRESS_POSTAL_CODE'=>'Postal Code:',
'LBL_ADDRESS_CITY'=>'City:',
'LBL_ADDRESS_COUNTRY'=>'Country:',
'LBL_ADDRESS_STATE'=>'State:',
'LBL_ADDRESS'=>'Address:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',
'LBL_DESCRIPTION'=>'Description:',

'LBL_CONVERT_LEAD'=>'Convert Lead:',
'LBL_CONVERT_LEAD_INFORMATION'=>'Convert Lead Information',
'LBL_ACCOUNT_NAME'=>'Account Name',
'LBL_POTENTIAL_NAME'=>'Potential Name',
'LBL_POTENTIAL_CLOSE_DATE'=>'Potential Close Date',
'LBL_POTENTIAL_AMOUNT'=>'Potential Amount',
'LBL_POTENTIAL_SALES_STAGE'=>'Potential Sales Stage',


'NTC_DELETE_CONFIRMATION'=>'Are you sure you want to delete this record?',
'NTC_REMOVE_CONFIRMATION'=>'Are you sure you want to remove this contact from this case?',
'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION'=>'Are you sure you want to remove this record as a direct vtiger_report?',
'NTC_REMOVE_OPP_CONFIRMATION'=>'Are you sure you want to remove this contact from this opportunity?',
'ERR_DELETE_RECORD'=>"en_us A record number must be specified to delete the contact.",
'NTC_COPY_PRIMARY_ADDRESS'=>'Copy primary address to alternate address',
'NTC_COPY_ALTERNATE_ADDRESS'=>'Copy alternate address to primary address',

// Added vtiger_fields in fetchfile.php, import.php -- crm4-Beta
'LBL_COLON'=>' : ', 
'LBL_IMPORT_LEADS'=>'Import Leads',
'LBL_LEADS_FILE_LIST'=>'Leads File List',
'LBL_INSTRUCTIONS'=>'Instructions',
'LBL_KINDLY_PROVIDE_AN_XLS_FILE'=>'Kindly provide an .xls file alone as input',
'LBL_PROVIDE_ATLEAST_ONE_FILE'=>'Please provide at least one file as input',

'LBL_NONE'=>'None',
'LBL_ASSIGNED_TO'=>'Assigned To:',
'LBL_SELECT_LEAD'=>'Select Lead',
'LBL_GENERAL_INFORMATION'=>'General Information',
'LBL_DO_NOT_CREATE_NEW_POTENTIAL'=>'Do not create a New Potential upon Conversion',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TASK'=>'New Task',
'LBL_TASK_TITLE'=>'Tasks',
'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',
'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',
'LBL_NEW_EMAIL'=>'New Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'New Note',
'LBL_NOTE_TITLE'=>'Notes',
'LBL_NEW_ATTACHMENT'=>'New Attachment',
'LBL_ATTACHMENT_TITLE'=>'Attachments',


//Added vtiger_fields after RC1 - Release 
'LBL_ALL'=>'All',
'LBL_CONTACTED'=>'Contacted',
'LBL_LOST'=>'Lost',
'LBL_HOT'=>'Hot',
'LBL_COLD'=>'Cold',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Lead Tools',

'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE'=>'Select template to Mail Merge:',

//Added for 4GA
'Salutation'=>'Salutation',
'First Name'=>'First Name',
'Phone'=>'Phone',
'Last Name'=>'Last Name',
'Mobile'=>'Mobile',
'Company'=>'Company',
'Fax'=>'Fax',
'Email'=>'Email',
'Lead Source'=>'Lead Source',
'Website'=>'Website',
'Annual Revenue'=>'Annual Revenue',
'Lead Status'=>'Lead Status',
'Industry'=>'Industry',
'Rating'=>'Rating',
'No Of Employees'=>'No Of Employees',
'Assigned To'=>'Assigned To',
'Yahoo Id'=>'Yahoo Id',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Street'=>'Street',
'Postal Code'=>'Postal Code',
'City'=>'City',
'Country'=>'Country',
'State'=>'State',
'Description'=>'Description',
'Po Box'=>'PO Box',
'Campaign Source'=>'Campaign Source',
//Added for CustomView 4.2 Release
'Name'=>'Name',
'LBL_NEW_LEADS'=>'My New Leads',

//Added for Existing Picklist Entries

'--None--'=>'--None--',
'Mr.'=>'Mr.',
'Ms.'=>'Ms.',
'Mrs.'=>'Mrs.',
'Dr.'=>'Dr.',
'Prof.'=>'Prof.',

'Acquired'=>'Acquired',
'Active'=>'Active',
'Market Failed'=>'Market Failed',
'Project Cancelled'=>'Project Cancelled',
'Shutdown'=>'Shutdown',

'Apparel'=>'Apparel',
'Banking'=>'Banking',
'Biotechnology'=>'Biotechnology',
'Chemicals'=>'Chemicals',
'Communications'=>'Communications',
'Construction'=>'Construction',
'Consulting'=>'Consulting',
'Education'=>'Education',
'Electronics'=>'Electronics',
'Energy'=>'Energy',
'Engineering'=>'Engineering',
'Entertainment'=>'Entertainment',
'Environmental'=>'Environmental',
'Finance'=>'Finance',
'Food & Beverage'=>'Food & Beverage',
'Government'=>'Government',
'Healthcare'=>'Healthcare',
'Hospitality'=>'Hospitality',
'Insurance'=>'Insurance',
'Machinery'=>'Machinery',
'Manufacturing'=>'Manufacturing',
'Media'=>'Media',
'Not For Profit'=>'Not For Profit',
'Recreation'=>'Recreation',
'Retail'=>'Retail',
'Shipping'=>'Shipping',
'Technology'=>'Technology',
'Telecommunications'=>'Telecommunications',
'Transportation'=>'Transportation',
'Utilities'=>'Utilities',
'Other'=>'Other',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Existing Customer',
'Self Generated'=>'Self Generated',
'Employee'=>'Employee',
'Partner'=>'Partner',
'Public Relations'=>'Public Relations',
'Direct Mail'=>'Direct Mail',
'Conference'=>'Conference',
'Trade Show'=>'Trade Show',
'Web Site'=>'Web Site',
'Word of mouth'=>'Word of mouth',

'Attempted to Contact'=>'Attempted to Contact',
'Cold'=>'Cold',
'Contact in Future'=>'Contact in Future',
'Contacted'=>'Contacted',
'Hot'=>'Hot',
'Junk Lead'=>'Junk Lead',
'Lost Lead'=>'Lost Lead',
'Not Contacted'=>'Not Contacted',
'Pre Qualified'=>'Pre Qualified',
'Qualified'=>'Qualified',
'Warm'=>'Warm',

// Added/Updated for vtiger CRM 5.0.4

'Designation'=>'Title',
     

);

?>
